setEndTime method

EventSchedulerBuilder setEndTime(
  1. DateTime time
)

Sets when the event should stop recurring.

Optional parameter that specifies when the event should stop recurring. If not set, the event will continue until maxRecurrences if set.

Implementation

EventSchedulerBuilder setEndTime(DateTime time) {
  _endTime = time;
  return this;
}