setEventKey method
Sets the unique identifier for the event.
This is a required parameter and must be set before building.
Implementation
EventSchedulerBuilder setEventKey(String key) {
_eventKey = key;
return this;
}
Sets the unique identifier for the event.
This is a required parameter and must be set before building.
EventSchedulerBuilder setEventKey(String key) {
_eventKey = key;
return this;
}