register static method

void register(
  1. SchedulerConfig config
)

Registers a new event configuration.

This method sets up the event with the provided configuration and starts tracking it according to its trigger type.

For time-based triggers, it will start the time tracking immediately.

Throws an exception if the configuration is invalid.

Implementation

static void register(SchedulerConfig config) {
  _configs[config.eventKey] = config;

  if (config.triggerType == TriggerType.time) {
    _startTimeTracking(config);
  }
}