setMaxRecurrences method
Sets the maximum number of times an event can recur.
Optional parameter that limits the total number of recurrences.
If not set, the event can recur indefinitely (until endTime if set).
Implementation
EventSchedulerBuilder setMaxRecurrences(int count) {
_maxRecurrences = count;
return this;
}