setOnStateUpdate method
Sets the callback function for state updates.
Optional parameter that will be called when the event's state changes. The callback receives a boolean indicating if the event is active.
Implementation
EventSchedulerBuilder setOnStateUpdate(Function(bool) callback) {
_onStateUpdate = callback;
return this;
}